
%% scatter individual waves
figure
plot(blist(:,3),blist(:,2),'b.')
set(gca,'YDir','reverse')
xlabel('t')
ylabel('h')

%% ------------------------   Scatter  ----------------------------------  
%% Plot SLJH and SLJT
% SLJH
figure
subplot(1,2,1)
contour(H,J*(10^-6),SLJH,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('P_L(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

% SLJT
subplot(1,2,2)
contour(T,J*(10^-6),SLJT,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('P_L(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(2),'-dpsc','figure/ch1/sljx.eps')

%% Plot J_SLJH and J_SLJT
% J_SLJH
figure
subplot(1,2,1)
contour(H,J*(10^-6),J_SLJH*(10^-6),[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('J \times P_L(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

% J_SLJT
subplot(1,2,2)
contour(T,J*(10^-6),J_SLJT*(10^-6),[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('J \times P_L(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(3),'-dpsc','figure/ch1/jsljx.eps')

%% -------------------------  Smoothed curves ----------------------------
%% Plot PLJH and PLJT
% PLJH
figure
subplot(1,2,1)
contour(H,J*(10^-6),PLJH,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('P_L(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

% PLJT
subplot(1,2,2)
contour(T,J*(10^-6),PLJT,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('P_L(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(4),'-dpsc','figure/ch1/pljx.eps')

%% Plot J_PLJH and J_PLJT
% J_PLJH
figure
subplot(1,2,1)
contour(H,J*(10^-6),J_PLJH*(10^-6),[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('J \times P_L(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

% J_PLJT
subplot(1,2,2)
contour(T,J*(10^-6),J_PLJT*(10^-6),[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('J \times P_L(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(5),'-dpsc','figure/ch1/jpljx.eps')


%% -------------------------  Efficiency  --------------------------------

%% Power matrix of the heaving buoy [kW]
figure
subplot(1,2,1)
contourf(Tpb,Hsb,hb)
title('Power absorption [kW]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

subplot(1,2,2)
contourf(Tpb,Hsb,effhb)
title('Efficiency [%]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(6),'-dpsc','figure/ch3/hb.eps')

%% Power matrix of the heaving two bodies system [kW]
figure
subplot(1,2,1)
contourf(Tpb,Hsb,htbs)
title('Power absorption [kW]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

subplot(1,2,2)
contourf(Tpb,Hsb,effhtbs)
title('Efficiency [%]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(7),'-dpsc','figure/ch3/htbs.eps')

%% Power matrix of the pitching device [kW]
figure
subplot(1,2,1)
contourf(Tpb,Hsb,pd)
title('Power absorption [kW]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

subplot(1,2,2)
contourf(Tpb,Hsb,effpd)
title('Efficiency [%]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(8),'-dpsc','figure/ch3/pd.eps')

%% Power matrix of the floating OWC
figure
subplot(1,2,1)
contourf(Tpb,Hsb,fowc)
title('Power absorption [kW]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

subplot(1,2,2)
contourf(Tpb,Hsb,efffowc)
title('Efficiency [%]')
xlabel('T_p[s]')
ylabel('H_s[m]')
colorbar

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(9),'-dpsc','figure/ch3/fowc.eps')

%------------------------------------------------------------
%% Efficiency matrix of the heaving buoy [kW]
figure
subplot(1,2,1)
contour(H,J*(10^-6),effhbL_JH,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{hb}}(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

subplot(1,2,2)
contour(T,J*(10^-6),effhbL_JT,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{hb}}(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(10),'-dpsc','figure/ch4/LEhb.eps')

%% Efficiency matrix of the heaving two bodies system [kW]
figure
subplot(1,2,1)
contour(H,J*(10^-6),effhtbsL_JH,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{htbs}}(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

subplot(1,2,2)
contour(T,J*(10^-6),effhtbsL_JT,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{htbs}}(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(11),'-dpsc','figure/ch4/LEhtbs.eps')

%% Efficiency matrix of the pitching device [kW]
figure
subplot(1,2,1)
contour(H,J*(10^-6),effpdL_JH,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{pd}}(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

subplot(1,2,2)
contour(T,J*(10^-6),effpdL_JT,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{pd}}(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(12),'-dpsc','figure/ch4/LEpd.eps')

%% Efficiency matrix of the floating OWC
figure
subplot(1,2,1)
contour(H,J*(10^-6),efffowcL_JH,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{fowc}}(J,H)')
xlabel('H[m]')
ylabel('J[MW]')

subplot(1,2,2)
contour(T,J*(10^-6),efffowcL_JT,[0.00001 0.0001 0.001 0.005 0.01 0.05 0.1 0.2])
title('p_{L,\eta_{fowc}}(J,T)')
xlabel('T[s]')
ylabel('J[MW]')

set(gcf, 'PaperType', 'B5')
set(gcf,'PaperUnits','centimeters','PaperPosition', [0.63, 0.63, 15.0, 7.0]);
print(figure(13),'-dpsc','figure/ch4/LEfowc.eps')

